const { ipcMain, dialog } = require("electron");
const { spawn } = require("child_process");
const { basename, join, posix } = require("path");
const { copyFileSync } = require("fs");

const handler = () => {
  ipcMain.on("terminal", (_, data) => {
    if (process.platform === "win32") {
      spawn("cmd", ["/c", "start", "docker", "exec", "-it", data, "sh"]);
    } else {
      spawn("exo-open", [
        "--launch",
        "TerminalEmulator",
        "docker",
        "exec",
        "-it",
        data,
        "sh"
      ]);
    }
  });
  ipcMain.on("viewer", (_, data) => {
    spawn("remote-viewer", [
      `spice://localhost:${data}`,
      "-f",
      "-t",
      "Oyun Parkı"
    ]);
  });
  ipcMain.on("upload", (_, data) => {
    const { Id, Source, Target, Username } = data;
    dialog
      .showOpenDialog({
        properties: ["openFile", "multiSelections"]
      })
      .then(result => {
        if (result.canceled) {
          return;
        }
        result.filePaths.map(f => {
          copyFileSync(f, join(Source, basename(f)));
          spawn("docker", [
            "exec",
            Id,
            "cp",
            "-r",
            `${posix.join(Target, basename(f))}`,
            `/home/${Username}/Desktop/`
          ]);
          spawn("docker", [
            "exec",
            Id,
            "chown",
            `${Username}:${Username}`,
            `/home/${Username}/Desktop/${basename(f)}`
          ]);
        });
      })
      .catch(err => {
        console.log(err);
      });
  });
};

module.exports = handler;
